summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--alternative_nick.py (renamed from alternativ_nick.py)26
-rw-r--r--debian/changelog2
-rw-r--r--debian/control4
-rw-r--r--debian/copyright2
-rw-r--r--debian/install2
5 files changed, 18 insertions, 18 deletions
diff --git a/debian/changelog b/debian/changelog
index e971ee6..2b56c53 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,4 +1,4 @@
-phenny-module-alternativ-nick (0.1) UNRELEASED; urgency=low
+phenny-module-alternative-nick (0.1) UNRELEASED; urgency=low
* Initial release.
diff --git a/debian/control b/debian/control
index 3bda754..0cac883 100644
--- a/debian/control
+++ b/debian/control
@@ -1,4 +1,4 @@
-Source: phenny-module-alternativ-nick
+Source: phenny-module-alternative-nick
Section: python
Priority: optional
Maintainer: Alexander Sulfrian <alex@spline.inf.fu-berlin.de>
@@ -7,7 +7,7 @@ Standards-Version: 3.8.3
Build-Depends: debhelper (>= 7.2.11)
Homepage: http://inamidst.com/phenny/
-Package: phenny-module-alternativ-nick
+Package: phenny-module-alternative-nick
Architecture: all
Depends: ${misc:Depends}, phenny
Description: alternativ nick module for phenny
diff --git a/debian/copyright b/debian/copyright
index f8739d7..bcf6330 100644
--- a/debian/copyright
+++ b/debian/copyright
@@ -4,7 +4,7 @@ This work was packaged for Debian by:
It was downloaded from:
- http://git.spline.inf.fu-berlin.de/phenny/modules/alternativ-nick/
+ http://git.spline.inf.fu-berlin.de/phenny/modules/alternative-nick/
Upstream Author(s):
diff --git a/debian/install b/debian/install
index 3a0cbb9..ec05e32 100644
--- a/debian/install
+++ b/debian/install
@@ -1 +1 @@
-alternativ_nick.py usr/share/phenny/modules/alternativ-nick/
+alternative_nick.py usr/share/phenny/modules/alternative-nick/
diff --git a/alternativ_nick.py b/alternative_nick.py
index 9041f21..66f958c 100644
--- a/alternativ_nick.py
+++ b/alternative_nick.py
@@ -1,6 +1,6 @@
#!/usr/bin/env python
"""
-alternativ_nick.py - Use an alternativ nick, if your choosen nick is already taken
+alternative_nick.py - Use an alternative nick, if your choosen nick is already taken
Copyright 2016, Alexander Sulfrian <alex@spline.inf.fu-berlin.de>
Licensed under the Eiffel Forum License 2.
@@ -36,24 +36,24 @@ def _set_nick(wrapper, nick):
def _build_nick(phenny):
# We have different ways to generate an alternativ_nick:
# * First we try to use the config option.
# * If it is not set or it does not work, we append an underscore after the
# default nick.
# * If even this did not work, we append a number and count upwards until a
# valid nick is found.
- alternativ_nick = getattr(phenny.config, 'alternativ_nick', None)
- if alternativ_nick is not None and phenny.nick != alternativ_nick:
- return alternativ_nick
+ alternative_nick = getattr(phenny.config, 'alternative_nick', None)
+ if alternative_nick is not None and phenny.nick != alternative_nick:
+ return alternative_nick
else:
- if phenny.data.get('alternativ_nick.count') is not None:
- count = phenny.data['alternativ_nick.count']
+ if phenny.data.get('alternative_nick.count') is not None:
+ count = phenny.data['alternative_nick.count']
count += 1
- phenny.data['alternativ_nick.count'] = count
+ phenny.data['alternative_nick.count'] = count
return ('%s_%d' % (phenny.config.nick, count))
else:
- phenny.data['alternativ_nick.count'] = 0
+ phenny.data['alternative_nick.count'] = 0
return ('%s_' % phenny.config.nick)
@@ -62,12 +62,12 @@ def nickname_in_use(phenny, input):
# supplied nick is already taken, or if we try to get the default nick and
# it is still taken. We remember the connection state, to decide what to
# do.
- if phenny.data.get('alternativ_nick.connected'):
+ if phenny.data.get('alternative_nick.connected'):
_start_nickloop(phenny)
else:
new_nick = _build_nick(phenny)
_set_nick(phenny, new_nick)
- phenny.data['alternativ_nick.active'] = True
+ phenny.data['alternative_nick.active'] = True
phenny.write(('NICK', new_nick))
nickname_in_use.rule = r'(.*)'
nickname_in_use.event = '433'
@@ -91,8 +91,8 @@ def connected(phenny, input):
# The '001' event is the first message after establishing the connection
# and providing a valid NICK and USER. If we used an alternativ nick, we
# could start trying to get back the default nick.
- phenny.data['alternativ_nick.connected'] = True
- if phenny.data.get('alternativ_nick.active'):
+ phenny.data['alternative_nick.connected'] = True
+ if phenny.data.get('alternative_nick.active'):
_start_nickloop(phenny)
connected.rule = r'(.*)'
connected.event = '001'
@@ -36,24 +36,24 @@ def _set_nick(wrapper, nick):
def _build_nick(phenny):
- # We have different ways to generate an alternativ_nick:
+ # We have different ways to generate an alternative_nick:
# * First we try to use the config option.
# * If it is not set or it does not work, we append an underscore after the